/*
	AI Landing by Heli - by Enigx
	
	AILandByHeli_OpenMe.sqf
	
	The script orders the landing of AI units via a helicopter on markers placed on the map from editor.
	The helicopter moves on specified waypoints and lands, disembarks units and flies to an escape point where it is canceled, or in alternative it stays where landed.
	Units can be moved on a routes of markers also positioned on the map by the editor.
	
	Operation and procedural steps for the script:
	1) Put empty markers on the map to identify the route of the waypoints that you want the helicopter to do. Name the markers	(es: M_1, M_2,... , Mn)
	2) Put empty markers on the map to identify the route of the waypoints that you want the units to do (route will start from Mn). Name the markers	(es: U_1, U_2,... , Un)
	3) Put empty markers on the map to identify the heli escape direction from landing position
	4) Put this folder AILandByHeli\ into mission folder
	5) Add trigger from editor to activate the system, specifying the following string in its OnActivation field:
		
				null = execVM "AILandByHeli\AILandByHeli_OpenMe.sqf";
					
	6) Compile this file AILandByHeli_OpenMe.sqf to define the AI heli transport by a call having the following form: 
		
	null = [HELI, ["MarkerHeli_1","MarkerHeli_2",...],[BEHAVIOR,"EscapeMarker"],FACTION,[Unit_1,Unit_2,...],["MarkerUnits_1","MarkerUnits_2",...]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";

	Arguments:
		0: classname of the heicopter to spawn - <STRING>
		1: Markers of the waypoints of the HELICOPTER - <ARRAY> - Name of (empty) markers placed on map composing the waypoints of route. The first is the spawing position.
			 The last the landing position. 2 markers as minimum to be placed
		2: Behavior of the helicopter on landing - <ARRAY> 
				- BEHAVIOR - <NUMBER>:	0 if you want the helicopter to take off towards the escape and cancellation marker once it has landed
																1 if it has to turn off the engine and stay on landing position
				- EscapeMarker - <STRING>: name of the escape direction marker with respect to the landing point.
					***NOTE: THE HELICOPTER IS CANCELED 3 km AFTER THIS MARKER IN THE SELECTED DIRECTION
					***NOTE: THIS MARKER MUST ALWAYS BE INDICATED EVEN IF NOT USED (BEHAVIOR = 1) !!! In case repeat one of the above	markers name
		3: Faction of units to be created (east,west,civilian,independent)
		4: Classnames of the units to be created - <ARRAY> - units to be inserted <STRING>.
		5: Markers of the waypoints of UNITS - <ARRAY> - Name of (empty) markers on map composing the waypoints of route of the units. Once disembarked, they will follow the assigned route 
		   in the given order. 1 marker as minimum
		
		NOTE: IF THE CAPACITY OF THE HELICOPTER (THE AVAILABLE FREE SEATS) IS LESS THAN THE NUMBER OF SPECIFIED UNITS, IT WILL BE FILLED UP TO ITS MAXIMUM CAPACITY.
		REMAINING ARRAY UNITS WILL BE IGNORED.
		
		Examples
	- The specified helicopter completes the route "M", lands on M_3, lands 3 blufor units that will move according to the route "U", then takes off again in the direction of M_4 and is canceled after 3km 
		null = ["RHS_CH_47F_10", ["M_1","M_2","M_3"],[0,"M_4"],west, ["rhsusf_army_ucp_arb_rifleman","rhsusf_army_ucp_arb_riflemanat","rhsusf_army_ucp_arb_machinegunner"],["U_1","U_2","U_3"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";	
	
	- The specified helicopter completes the route "M", lands on M_2, lands 2 independent units that will move according to the route "A", then stays on M_2 with engine switched off	
		null = ["O_Heli_Light_02_unarmed_F", ["M_1","M_2"],[1,"M_1"],independent, ["O_Soldier_TL_F","O_Soldier_F"],["A_1","A_2","A_3","A_4"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";	
	
	- It is possible to add more helicopters by consecutive calls, varying the vehicles, the units and markers				
		null = ["RHS_CH_47F_10", ["M_1","M_2","M_3"],[0,"M_4"],east, ["LOP_ISTS_OPF_Infantry_Rifleman_5","LOP_ISTS_OPF_Infantry_GL"],["U_1","U_2","U_3"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";					
		sleep 2; // ***** IMPORTANT: IN THIS CASE, INSERT A SLEEP OF 2 SECONDS TO DELAY THE DIFFERENT CALLS BETWEEN THEM ***************			
		null = ["O_Heli_Light_02_unarmed_F", ["M6","M7","M8","M9","M10"],[1,"M6"],east, ["O_Soldier_TL_F","O_Soldier_F"],["A_1"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";	

	*** Case with random selection of calls
		// define an array with different parameters of heli, units and markers
		_arrayUnitsToLand = 
		[
		["RHS_CH_47F_10", ["F_1","F_2","F_3"],[0,"F_4"],east, ["LOP_ISTS_OPF_Infantry_Rifleman_5","LOP_ISTS_OPF_Infantry_GL"],["U_1","U_2","U_3"]],
		["O_Heli_Light_02_unarmed_F", ["M_1","M_2"],[1,"M_1"],independent, ["O_Soldier_TL_F","O_Soldier_F"],["A_1","A_2","A_3","A_4"],
		["RHS_CH_47F_10", ["G_1","G_2","G_3"],[0,"G_4"],east, ["LOP_ISTS_OPF_Infantry_Rifleman_5","LOP_ISTS_OPF_Infantry_GL","LOP_ISTS_OPF_Infantry_Rifleman_5"],["H1","H2","H3","H4","H5"]]		
		];
		// pass a random array call to the function
		null = selectRandom _arrayUnitsToLand execVM "AILandByHeli\AILandingByHeli_V2.sqf";	

	*** Case with random selection of both calls, units and markers
		// define an array with different parameters of vehicles, units and marker routes
		_arrayHeli = [
		"RHS_CH_47F_10",
		"O_Heli_Light_02_unarmed_F"
		];
		_arrayHeliMark =
		[
		["B1","B2"],
		["A1","A2","A3","A4"]
		];		
		_arrayUnits =
		[
		["O_Soldier_TL_F","O_Soldier_AT_F","O_Soldier_AR_F","O_Soldier_F"],
		["O_Soldier_F","O_Soldier_F","O_Soldier_F"],
		["O_Soldier_F","O_Soldier_AR_F","O_Soldier_F","O_Soldier_AT_F","O_Soldier_F","O_Soldier_F"],
		["O_Soldier_F"]
		];
		_arrayUnMark =
		[
		["M1","M2","M3","M4","M5"],
		["M6","M7","M8"],
		["M9","M10","M11"],
		["K1","K2","K3"],
		["A_1"]
		];
		
		// pass one or more random calls of the arrays to the function
		null = [selectRandom _arrayHeli, selectRandom _arrayHeliMark,[0,"EscapeMkr"],east, selectRandom _arrayUnits, selectRandom _arrayUnMark] execVM "AILandByHeli\AILandingByHeli_V2.sqf";	


HOW TO RUN THE SYSTEM 
	-- By Trigger in editor as reported above. So use a trigger with the following string into its OnActivation field:
	
				null = execVM "AILandByHeli\AILandByHeli_OpenMe.sqf";

	-- By ACE self interaction menu (OPTION)
		You can use ace menu to start system ad activate it in game whenever you want.
		NOTE: OF COURSE YOU NEED THE ACE MOD LOADED IN YOUR MISSION TO USE THIS METHOD
			
		1) create initPlayerLocal.sqf in mission folder (if not already present)
		2) Add these strings in initPlayerLocal.sqf
			
				authPlayers = ["XXXXXXXXX"];	// <-- ADD HERE THE STEAM ID OF THE PLAYER/S ENABLED TO ACTIVATE THE CYCLE OF ATTACKS BY ACE COMMANDS
				_uidP = getPlayerUID player;
				if (_uidP in authPlayers) then {
				    _actionLH = {execVM "AILandByHeli\AILandByHeli_OpenMe.sqf";};
						_AILdHeli = ['AILandByHeli', 'Activate AI Landing By Heli', '', _actionLH, {true}] call ace_interact_menu_fnc_createAction;
						[player, 1, ["ACE_SelfActions"], _AILdHeli] call ace_interact_menu_fnc_addActionToObject;
					
				};
	
		NOTE: For obvious reasons not all players will be enabled to activate the script, but only the mission master with the specified ID
		Note: you have to run mission in MP also from editor to work with the Steam ID!
	  
*/


// ** MODIFY HERE BELOW TO INSERT THE SCRIPT CALL, AS DESCRIBED ABOVE IN EXAMPLES

null = ["B_Heli_Transport_01_F", ["M_1","M_2","M_3","M_4"],[0,"E_1"],west, ["B_Soldier_SL_F","B_Soldier_TL_F","B_soldier_LAT_F","B_soldier_AR_F","B_Soldier_F"],["A_1","A_2","A_3"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";
sleep 2;
null = ["B_Heli_Transport_01_F", ["C_1","C_2","C_3"],[1,"C_1"],west, ["B_Soldier_SL_F","B_Soldier_TL_F","B_soldier_LAT_F","B_soldier_AR_F","B_Soldier_F"],["B_1","B_2"]] execVM "AILandByHeli\AILandingByHeli_V2.sqf";






    